==> apache-camel-3.14.6-src.zip: apache-camel-3.14.6/components/camel-stream/src/test/java/org/apache/camel/component/stream/StreamDelayTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.stream;

import org.apache.camel.builder.RouteBuilder;
import org.apache.camel.test.junit5.CamelTestSupport;
import org.junit.jupiter.api.Test;

import static org.junit.jupiter.api.Assertions.assertTrue;

/**
 * Unit test for delay option.
 */
public class StreamDelayTest extends CamelTestSupport {

    @Test
    public void testStringContent() throws Exception {
        long start = System.currentTimeMillis();
        template.sendBody("direct:in", "Hello Text World\n");
        long delta = System.currentTimeMillis() - start;
        assertTrue(delta > 1900 && delta < 3000, "Delay should be around 2 sec: " + delta);
    }

    @Override
    protected RouteBuilder createRouteBuilder() {
        return new RouteBuilder() {
            public void configure() {
                from("direct:in").to("stream:out?delay=2000");
            }
        };
    }

}

==> apache-camel-4.0.1-src.zip: apache-camel-4.0.1/components/camel-stream/src/test/java/org/apache/camel/component/stream/StreamDelayTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.stream;

import org.apache.camel.builder.RouteBuilder;
import org.apache.camel.test.junit5.CamelTestSupport;
import org.junit.jupiter.api.Test;

import static org.junit.jupiter.api.Assertions.assertTrue;

/**
 * Unit test for delay option.
 */
public class StreamDelayTest extends CamelTestSupport {

    @Test
    public void testStringContent() {
        long start = System.currentTimeMillis();
        template.sendBody("direct:in", "Hello Text World\n");
        long delta = System.currentTimeMillis() - start;
        assertTrue(delta > 1900 && delta < 3000, "Delay should be around 2 sec: " + delta);
    }

    @Override
    protected RouteBuilder createRouteBuilder() {
        return new RouteBuilder() {
            public void configure() {
                from("direct:in").to("stream:out?delay=2000");
            }
        };
    }

}
